BalanceResponseBean class

Annotations
  • @JsonSerializable.new()

Constructors

BalanceResponseBean(String? address, BigInt? greenBalance, BigInt? redBalance, BigInt? greenPenalty, BigInt? redPenalty, int? penaltySlots, String? generatorSith)
BalanceResponseBean.fromJson(Map<String, dynamic> json)
factory

Properties

address String?
getter/setter pair
generatorSith String?
getter/setter pair
greenBalance BigInt?
getter/setter pair
greenPenalty BigInt?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
penaltySlots int?
getter/setter pair
redBalance BigInt?
getter/setter pair
redPenalty BigInt?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited