parseUri static method
Parameter: url (String). Functionality: This method takes a url string and parses it into a Uri object. The Uri.parse method is used to parse the url string and create a Uri object. The created Uri object is returned.
Implementation
static Uri parseUri(String url){
return Uri.parse(url);
}