getWalletDir static method

Future<Directory> getWalletDir(
  1. String walletDirName
)

This method asynchronously retrieves the application's documents directory and then creates a new Directory object representing a specific wallet directory within that path.

Implementation

static Future<Directory> getWalletDir(String walletDirName) async {
  Directory appDocDir = await getApplicationDocumentsDirectory();
  return Directory(path.join(appDocDir.path,walletDirName));
}