KeyBean class

Annotations
  • @JsonSerializable.new()

Constructors

KeyBean(String version, String algorithm, String cypher, String seed, String words)
KeyBean.fromJson(Map<String, dynamic> json)
factory

Properties

algorithm String
getter/setter pair
cypher String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed String
getter/setter pair
version String
getter/setter pair
words String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited