StakeNode class

Annotations
  • @JsonSerializable.new()

Constructors

StakeNode(String address, String shortAddress, String alias, int nrOverflow, int stakeUntilPenalty, int stakeToActivation, int activeStake, int epochEvaluated, int blocksSubmitted, int slotsAssigned, int holders, String identicon)
StakeNode.fromJson(Map<String, dynamic> json)
factory

Properties

activeStake int
getter/setter pair
address String
getter/setter pair
alias String
getter/setter pair
blocksSubmitted int
getter/setter pair
epochEvaluated int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
holders int
getter/setter pair
identicon String
getter/setter pair
nrOverflow int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortAddress String
getter/setter pair
slotsAssigned int
getter/setter pair
stakeToActivation int
getter/setter pair
stakeUntilPenalty int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited