TKmTK class

Constructors

TKmTK()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bigIntDoubleTK(BigInt unit) double
getTransactionTime() DateTime
In the takamaka blockchain each transaction has a time limit beyond which it cannot be included in a block. The transaction timer must be formatted as unix timestamp (with milliseconds) and set to between "current time" and "current time + 10 minutes". This enables the transaction to be included in the first available block for the next 10 minutes. Creating transactions with timer set to current time might work well for local testing but is unlikely to function when interacting with remote servers. To give a "sensible" inclusion window to the transaction and to account for possible clock errors of the nodes, the device doing the sending, and network transport times, it is recommended to place the transaction in the middle of the interval. To do this simply add 60000L * 5 (5 minutes) to the NOW(), current time.
stringBigIntDoubleTK(String unit) double
unitBigIntTK(BigInt unit) BigInt
unitStringTK(String unit) BigInt
unitTK(double unit) BigInt