TkmMetadata class

Annotations
  • @JsonSerializable.new()

Constructors

TkmMetadata([List<String>? tags, String? contentType, String? platform, String? xParsedBy, String? resourceName, String? mime, String? type, Map<String, dynamic>? extraMetadata, String? data])
TkmMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

contentType String?
getter/setter pair
data String?
getter/setter pair
extraMetadata Map<String, dynamic>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mime String?
getter/setter pair
platform String?
getter/setter pair
resourceName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
getter/setter pair
type String?
getter/setter pair
xParsedBy String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited