TransactionBox class
- Annotations
-
- @JsonSerializable.new()
Constructors
- TransactionBox([String? singleInclusionTransactionHash, String? transactionJson, TransactionBean? tb, InternalTransactionBean? itb, bool? valid])
-
TransactionBox.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itb ↔ InternalTransactionBean?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleInclusionTransactionHash ↔ String?
-
getter/setter pair
- tb ↔ TransactionBean?
-
getter/setter pair
- transactionJson ↔ String?
-
getter/setter pair
- valid ↔ bool?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited