blob static method
A Blob transaction in a blockchain is a type of transaction that stores binary data, such as a document or image, on the blockchain. This data is typically stored as a hash, which is a unique digital fingerprint of the data that can be used to verify its authenticity. Blob transactions are often used to store important documents, such as contracts, on a blockchain for secure and tamper-proof storage.
Implementation
static InternalTransactionBean blob(String from, message, DateTime notBefore) {
InternalTransactionBean result = common(TransactionType.BLOB, notBefore);
result.from = from;
message = utf8.decode(message.trim().codeUnits);
result.message = message = base64UrlEncode(utf8.encode(message));
result.transactionHash = StringUtilities.internalTransactionBeanHash(result);
return result;
}