ConsumerHelper class
The ConsumerHelper class is a Dart class that provides a static method doRequest() for making HTTP requests
Constructors
- ConsumerHelper()
- This is a constructor for the ConsumerHelper class. no specific initialization logic is defined.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
doJsonRequest(
HttpMethods method, String url, String body) → Future< String> -
doRequest(
HttpMethods method, String url, Map< String, dynamic> body) → Future<String> - This is a static method that performs an HTTP request. It takes three parameters: