In the takamaka blockchain each transaction has a time limit beyond which
it cannot be included in a block. The transaction timer must be formatted
as unix timestamp (with milliseconds) and set to between "current time"
and "current time + 10 minutes". This enables the transaction to be
included in the first available block for the next 10 minutes. Creating
transactions with timer set to current time might work well for local
testing but is unlikely to function when interacting with remote servers.
To give a "sensible" inclusion window to the transaction and to account
for possible clock errors of the nodes, the device doing the sending, and
network transport times, it is recommended to place the transaction in
the middle of the interval. To do this simply add 60000L * 5 (5 minutes)
to the NOW(), current time.