TkmWallet class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createGenericTransaction(
InternalTransactionBean itb, SimpleKeyPair keyPair, String publicKeyFrom) → Future< TransactionBean> -
verifySign(
TransactionBean tb, SimpleKeyPair keyPair) → Future< TkmCypherBean> -
verifyTransactionIntegrity(
String transactionJson, SimpleKeyPair keyPair) → Future< TransactionBox>